@@ -1,33 +1,33 @@
-from gitcms.simpletagging.models import Tag
-from gitcms.blog.models import BlogPost
+from gitcms.tagging.models import Tag
+from django.template import RequestContext
 from django.shortcuts import get_object_or_404, render_to_response
+from gitcms.blog.models import BlogPost
+
 
 def bytag(request, tag):
     tag = get_object_or_404(Tag, slug=tag)
-    posts = BlogPost.objects.filter(tags=tag).order_by('-timestamp')
+    posts = BlogPost.objects.exclude(status='draft').filter(tags=tag).order_by('-timestamp')
     return render_to_response(
-                'blog/list.html',
-                {
-                    'title' : 'Posts in %s' % tag,
-                    'pagetitle' : 'Latest posts in %s' % tag,
+                'blog/tag_list.html',
+                RequestContext(request, {
+                    'tag' : tag,
                     'posts' : posts,
-                })
+                }))
 
 def post(request, year, month, slug):
-    from os import path
-    post = get_object_or_404(BlogPost, year_month_slug=path.join(year, month, slug))
+    post = get_object_or_404(BlogPost, slug=slug)
     return render_to_response(
                 'blog/post.html',
-                {
+                RequestContext(request, {
                     'post' : post,
-                })
+                }))
 
 def mostrecent(request):
-    posts = BlogPost.objects.order_by('-timestamp')
+    posts = BlogPost.objects.exclude(status='draft').order_by('-timestamp')
     return render_to_response(
                 'blog/list.html',
-                {
+                RequestContext(request, {
                     'title' : 'New posts',
                     'pagetitle' : 'Latest posts',
                     'posts' : posts,
-                })
+                }))
