@@ -2,5 +2,5 @@ from django.conf.urls.defaults import *
 import views
 
 urlpatterns = patterns('',
-    (r'^(?P<url>.*)/?', views.book),
+    url(r'^(?P<url>.*)/?', views.book, name='books'),
 )
